import rox
from rox import g

# Classes

# Abstract class to wrap control and text retreival
class ControlWrapper:
	def __init__(self, data):
		self.label_string = ''
		self.name_string = ''
		self.default_string = ''
		self.main_widget = None
		self.pack_widget = None
		data_list = data.split(':', 2)
		self.num_entries = len(data_list)
		if self.num_entries == 3:
			self.label_string = data_list[0]
			self.name_string = data_list[1]
			self.default_string = data_list[2]
		elif self.num_entries == 2:
			self.label_string = data_list[0]
			self.default_string = data_list[1]
		else:
			self.default_string = data_list[0]
	def get_value(self):
		return ''
	def get_print_data(self):
		data = self.get_value()
		if self.name_string != '':
			return self.name_string + '=' + data
		else:
			return data
	def add_control(self, vbox):
		vbox.pack_start(self.pack_widget)
	
class EntryWrapper(ControlWrapper):
	def __init__(self, data):
		ControlWrapper.__init__(self, data)
		self.main_widget = g.Entry()
		self.main_widget.set_text(self.default_string)
		self.main_widget.set_activates_default(True)
		if self.num_entries == 3 or self.num_entries == 2:
			self.pack_widget = g.HBox()
			self.pack_widget.pack_start(g.Label(self.label_string))
			self.pack_widget.pack_start(self.main_widget)
		else:
			self.pack_widget = self.main_widget
	def get_value(self):
		return self.main_widget.get_text()

class ComboWrapper(ControlWrapper):
	def __init__(self, data):
		ControlWrapper.__init__(self, data)
		self.main_widget = g.Combo()
		popdown = self.default_string.split(',')
		self.main_widget.set_popdown_strings(popdown)
		self.main_widget.entry.set_activates_default(True)
		if self.num_entries == 3 or self.num_entries == 2:
			self.pack_widget = g.HBox()
			self.pack_widget.pack_start(g.Label(self.label_string))
			self.pack_widget.pack_start(self.main_widget)
		else:
			self.pack_widget = self.main_widget
	def get_value(self):
		return self.main_widget.entry.get_text()

class CheckWrapper(ControlWrapper, g.CheckButton):
	def __init__(self, data):
		ControlWrapper.__init__(self, data)
		g.CheckButton.__init__(self)
		self.main_widget = self
		self.pack_widget = self
		if self.default_string == '1':
			self.main_widget.set_active(True)
		else:
			self.main_widget.set_active(False)
		if self.num_entries == 3 or self.num_entries == 2:
			self.set_label(self.label_string)
	def get_value(self):
		val = self.get_active()
		if val:
			return '1'
		else: 
			return '0'
			
class OptionWrapper(ControlWrapper, g.VBox):
	def __init__(self, data):
		ControlWrapper.__init__(self, data)
		g.VBox.__init__(self)
		labels = self.default_string.split(',')
		self.option_group = None
		self.option_list = []
		self.main_widget = self
		optind = 0
		for lbl in labels:
			if self.option_group == None:
				self.option_list.append(g.RadioButton())
			else:
				self.option_list.append(g.RadioButton(self.option_list[optind]))
			optind = len(self.option_list) -1
			if self.option_group == None:
				self.option_group = self.option_list[optind].get_group()
			self.option_list[optind].set_label(lbl)
			self.pack_start(self.option_list[optind])
		self.pack_widget = self
	def get_value(self):
		val=''
		for opt in range(0,len(self.option_list)):
			if self.option_list[opt].get_active():
				val=opt
		return str(val)
